@@ -11,15 +11,22 @@ use Test::Requires { version => 0.88 };
 use Module::Build;
 use Sys::Hostname;
 
-my $builder; my $notes = {}; my $perl_ver;
+my ($builder, $host, $notes, $perl_ver);
 
 BEGIN {
-   $builder   = eval { Module::Build->current };
-   $builder and $notes = $builder->notes;
-   $perl_ver  = $notes->{min_perl_version} || 5.008;
-   $Bin =~ m{ : .+ : }mx and plan skip_all => 'Two colons in $Bin path';
-   $notes->{testing} and lc hostname eq 'digitalis'
-      and plan skip_all => 'Broken smoker a54c1c84-6bf5-1014-b4f9-dcd54300afcd';
+   $host     = lc hostname;
+   $builder  = eval { Module::Build->current };
+   $notes    = $builder ? $builder->notes : {};
+   $perl_ver = $notes->{min_perl_version} || 5.008;
+
+   if ($notes->{testing}) {
+      $Bin =~ m{ : .+ : }mx and
+         plan skip_all => 'Two colons in $Bin path';
+      $host eq 'digitalis'  and
+         plan skip_all => 'Broken smoker a54c1c84-6bf5-1014-b4f9-dcd54300afcd';
+      # TODO: Remove this when service is restored
+      plan skip_all => 'CPAN Testing down Aug 2015';
+   }
 }
 
 use Test::Requires "${perl_ver}";
